public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: Sumit Garg <sumit.garg@linaro.org>
To: edk2-devel@lists.01.org
Cc: tee-dev@lists.linaro.org, Sumit Garg <sumit.garg@linaro.org>,
	Ard Biesheuvel <ard.biesheuvel@linaro.org>,
	Leif Lindholm <leif.lindholm@linaro.org>
Subject: [PATCH v1 1/1] ArmPkg/OpteeLib: Add dummy RPC handler
Date: Wed,  5 Dec 2018 17:27:45 +0530	[thread overview]
Message-ID: <1544011065-31305-1-git-send-email-sumit.garg@linaro.org> (raw)

Add dummy RPC handler for RPCs that are not implemented as control
should be returned back to OP-TEE in case any RPC is invoked.

Cc: Ard Biesheuvel <ard.biesheuvel@linaro.org>
Cc: Leif Lindholm <leif.lindholm@linaro.org>
Contributed-under: TianoCore Contribution Agreement 1.1
Signed-off-by: Sumit Garg <sumit.garg@linaro.org>
---
 ArmPkg/Library/OpteeLib/OpteeSmc.h |  3 ++
 ArmPkg/Library/OpteeLib/Optee.c    | 34 ++++++++++++++++----
 2 files changed, 30 insertions(+), 7 deletions(-)

diff --git a/ArmPkg/Library/OpteeLib/OpteeSmc.h b/ArmPkg/Library/OpteeLib/OpteeSmc.h
index 9cccd81810c9..6209782aaed7 100644
--- a/ArmPkg/Library/OpteeLib/OpteeSmc.h
+++ b/ArmPkg/Library/OpteeLib/OpteeSmc.h
@@ -25,6 +25,9 @@
 
 #define OPTEE_SMC_SHARED_MEMORY_CACHED          1
 
+#define OPTEE_SMC_RETURN_UNKNOWN_FUNCTION       0xffffffff
+#define OPTEE_SMC_RETURN_RPC_PREFIX_MASK        0xffff0000
+#define OPTEE_SMC_RETURN_RPC_PREFIX             0xffff0000
 #define OPTEE_SMC_RETURN_RPC_FOREIGN_INTERRUPT  0xffff0004
 
 #define OPTEE_MESSAGE_COMMAND_OPEN_SESSION      0
diff --git a/ArmPkg/Library/OpteeLib/Optee.c b/ArmPkg/Library/OpteeLib/Optee.c
index 55dcc7853b59..ed2a03c593c2 100644
--- a/ArmPkg/Library/OpteeLib/Optee.c
+++ b/ArmPkg/Library/OpteeLib/Optee.c
@@ -123,6 +123,17 @@ OpteeInit (
   return EFI_SUCCESS;
 }
 
+STATIC
+BOOLEAN
+IsOpteeSmcReturnRpc (
+  UINT32 Return
+  )
+{
+  return (Return != OPTEE_SMC_RETURN_UNKNOWN_FUNCTION) &&
+         ((Return & OPTEE_SMC_RETURN_RPC_PREFIX_MASK) ==
+          OPTEE_SMC_RETURN_RPC_PREFIX);
+}
+
 /**
   Does Standard SMC to OP-TEE in secure world.
 
@@ -147,13 +158,22 @@ OpteeCallWithArg (
   while (TRUE) {
     ArmCallSmc (&ArmSmcArgs);
 
-    if (ArmSmcArgs.Arg0 == OPTEE_SMC_RETURN_RPC_FOREIGN_INTERRUPT) {
-      //
-      // A foreign interrupt was raised while secure world was
-      // executing, since they are handled in UEFI a dummy RPC is
-      // performed to let UEFI take the interrupt through the normal
-      // vector.
-      //
+    if (IsOpteeSmcReturnRpc (ArmSmcArgs.Arg0)) {
+      switch (ArmSmcArgs.Arg0) {
+      case OPTEE_SMC_RETURN_RPC_FOREIGN_INTERRUPT:
+        //
+        // A foreign interrupt was raised while secure world was
+        // executing, since they are handled in UEFI a dummy RPC is
+        // performed to let UEFI take the interrupt through the normal
+        // vector.
+        //
+        break;
+
+      default:
+         // Do nothing in case RPC is not implemented.
+        break;
+      }
+
       ArmSmcArgs.Arg0 = OPTEE_SMC_RETURN_FROM_RPC;
     } else {
       break;
-- 
2.7.4



             reply	other threads:[~2018-12-05 11:58 UTC|newest]

Thread overview: 2+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2018-12-05 11:57 Sumit Garg [this message]
2018-12-06 16:58 ` [PATCH v1 1/1] ArmPkg/OpteeLib: Add dummy RPC handler Ard Biesheuvel

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1544011065-31305-1-git-send-email-sumit.garg@linaro.org \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox